# gmailnotipy
`gmailnotipy` Watches your all gmail accounts and notifies you when an email arrives.

# Config
Place your credentials in `~/.config/gmailnotipy.json` as per following json format.
```
[
    {
        username: "gmail_account_1_username",
        password: "gmail_account_1_password"
    },
    {
        username: "gmail_account_2_username",
        password: "gmail_account_2_password"
    },
    {
        username: "gmail_account_2_username",
        password: "gmail_account_2_password"
    }
]

```
